<?xml version="1.0" encoding="utf-8"?>
<!--
	WasteX v1.09 - simple EDI for waste shipments

	Copyright (C) 2023 Environment Agency Austria
	Commissioned by the Austrian Federal Ministry of Environment (BMK)

	Contact: edm-helpdesk@umweltbundesamt.at

	Licensed under the EUPL, Version 1.2 or – as soon they will be approved
	by the European Commission – subsequent versions of the EUPL (the "Licence");

	You may not use this work except in compliance with the Licence.

	You may obtain a copy of the Licence at: http://joinup.ec.europa.eu/software/page/eupl

	Unless required by applicable law or agreed to in writing, work distributed under the licence is distributed
	on an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

	See the Licence for the specific language governing permissions and limitations under the Licence.
-->
<schema xmlns="http://purl.oclc.org/dsdl/schematron" xmlns:f="http://f.net/" xmlns:sch="http://purl.oclc.org/dsdl/schematron" xmlns:sqf="http://www.schematron-quickfix.com/validator/process" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" queryBinding="xslt2">
	<ns uri="http://www.eudin.org/schema/wastex_message" prefix="wxm"/>
	<ns uri="http://f.net/" prefix="f"/>
	<ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
	<xsl:function name="f:valNodeName" as="xs:string">
		<xsl:param name="ncontext" as="node()"/>
		<xsl:sequence select="if (exists($ncontext/ancestor::wxm:MessageValidationContext/wxm:ValidationNodeName)) then concat('»',$ncontext/ancestor::wxm:MessageValidationContext/wxm:ValidationNodeName,'«') else 'the validation node'"/>
	</xsl:function>
	<xsl:function name="f:msgNotID" as="xs:string">
		<xsl:param name="ncontext" as="node()"/>
		<xsl:sequence select="if (exists($ncontext/ancestor::wxm:MessageValidationContext/wxm:WasteMovementUserMessage/*/wxm:AnnouncementIdentity/wxm:NotificationID)) then ($ncontext/ancestor::wxm:MessageValidationContext/wxm:WasteMovementUserMessage/*/wxm:AnnouncementIdentity/wxm:NotificationID)[1] else ''"/>
	</xsl:function>
	<xsl:function name="f:msgSeqNumID" as="xs:string">
		<xsl:param name="ncontext" as="node()"/>
		<xsl:sequence select="if (exists($ncontext/ancestor::wxm:MessageValidationContext/wxm:WasteMovementUserMessage/*/wxm:AnnouncementIdentity/wxm:SequenceNumberID)) then ($ncontext/ancestor::wxm:MessageValidationContext/wxm:WasteMovementUserMessage/*/wxm:AnnouncementIdentity/wxm:SequenceNumberID)[1] else ''"/>
	</xsl:function>
	<xsl:function name="f:msgTypeName" as="xs:string">
		<xsl:param name="ncontext" as="node()"/>
		<xsl:variable name="nvalcontext" select="$ncontext/ancestor::wxm:MessageValidationContext"/>
		<xsl:sequence select="if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:MovementAnnouncement)) then 'movement announcement message' else (if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:MovementAnnouncementStatus)) then 'movement announcement status message' else (if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:CarrierConfirmation)) then 'carrier confirmation message' else (if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt)) then 'confirmation of waste receipt message' else (if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment)) then 'confirmation of waste treatment message' else 'message'))))"/>
	</xsl:function>
	<xsl:function name="f:dateName" as="xs:string">
		<xsl:param name="ncontext" as="node()"/>
		<xsl:variable name="nvalcontext" select="$ncontext/ancestor::wxm:MessageValidationContext"/>
		<xsl:sequence select="if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:MovementAnnouncement)) then 'shipment date' else (if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:MovementAnnouncementStatus)) then 'shipment date' else (if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:CarrierConfirmation)) then 'transfer date' else (if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt)) then 'waste receipt date' else (if (exists($nvalcontext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment)) then 'treatment completion date' else 'date'))))"/>
	</xsl:function>
	<xsl:function name="f:availContentTypesShort" as="xs:string*">
		<xsl:param name="ncontext" as="node()"/>
		<xsl:variable name="nvalcontext" select="$ncontext/ancestor::wxm:MessageValidationContext"/>
		<xsl:sequence select="(if (xs:boolean($nvalcontext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncementInDatabaseIndicator)) then 'movement announcement' else '', if (xs:integer($nvalcontext/wxm:ValidationNodeIndividualData/wxm:CarrierConfirmationInDatabaseCount) gt 0) then 'carrier confirmation' else '', if (xs:boolean($nvalcontext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceiptInDatabaseIndicator)) then 'confirmation of waste receipt' else '', if (xs:boolean($nvalcontext/wxm:ValidationNodeIndividualData/wxm:FacilityConfirmationOfWasteTreatmentInDatabaseIndicator) or xs:boolean($nvalcontext/wxm:ValidationNodeIndividualData/wxm:EntireConfirmationOfWasteTreatmentInDatabaseIndicator)) then 'confirmation of the completion of waste treatment' else '')[. != '']"/>
	</xsl:function>
	<xsl:function name="f:safeStringValue" as="xs:string">
		<xsl:param name="nelem" as="node()?"/>
		<xsl:sequence select="if (exists($nelem)) then ($nelem/text()) else ('')"/>
	</xsl:function>
	<xsl:function name="f:matchingPartyNodes" as="node()*">
		<xsl:param name="npartyavail" as="node()*"/>
		<xsl:param name="spartyid" as="xs:string"/>
		<xsl:param name="sregisterid" as="xs:string"/>
		<xsl:variable name="nmainmatch" select="$npartyavail[(wxm:PartyID eq $spartyid) and (wxm:PartyID/@registerID eq $sregisterid)]"/>
		<xsl:sequence select="if (count($nmainmatch) ge 1) then ($nmainmatch) else ($npartyavail[wxm:RecipientSpecificPartyID eq $spartyid])"/>
	</xsl:function>
	<xsl:function name="f:matchingTransportMovementNodes" as="node()*">
		<xsl:param name="ntransportmovementavail" as="node()*"/>
		<xsl:param name="scarrierpartyid" as="xs:string"/>
		<xsl:param name="sregisterid" as="xs:string"/>
		<xsl:variable name="nmainmatch" select="$ntransportmovementavail[(wxm:CarrierPartyID eq $scarrierpartyid) and (wxm:CarrierPartyID/@registerID eq $sregisterid)]"/>
		<xsl:sequence select="if (count($nmainmatch) ge 1) then ($nmainmatch) else ($ntransportmovementavail[wxm:RecipientSpecificCarrierPartyID eq $scarrierpartyid])"/>
	</xsl:function>
	<xsl:function name="f:matchingPartySiteNodes" as="node()*">
		<xsl:param name="npartysiteavail" as="node()*"/>
		<xsl:param name="spartyid" as="xs:string"/>
		<xsl:param name="sregisterid" as="xs:string"/>
		<xsl:param name="spostalareaid" as="xs:string"/>
		<xsl:variable name="nmainmatch" select="$npartysiteavail[(wxm:PartyID eq $spartyid) and (wxm:PartyID/@registerID eq $sregisterid) and (wxm:SitePostalAreaID eq $spostalareaid)]"/>
		<xsl:sequence select="if (count($nmainmatch) ge 1) then ($nmainmatch) else ($npartysiteavail[(wxm:RecipientSpecificPartyID eq $spartyid) and (wxm:SitePostalAreaID eq $spostalareaid)])"/>
	</xsl:function>
	<xsl:function name="f:concatID" as="xs:string">
		<xsl:param name="sida" as="xs:string"/>
		<xsl:param name="sidb" as="xs:string"/>
		<xsl:param name="ssep" as="xs:string"/>
		<xsl:sequence select="if ($sida ne '') then (if ($sidb ne '') then (concat($sida,$ssep,$sidb)) else ($sida)) else ($sidb)"/>
	</xsl:function>
	<xsl:function name="f:listPartyID" as="xs:string">
		<xsl:param name="nparty" as="node()"/>
		<xsl:param name="ssep" as="xs:string"/>
		<xsl:variable name="sidwastex" select="if (exists($nparty/wxm:PartyID)) then (concat('WasteX relevant ID »',$nparty/wxm:PartyID/text(),'« (»',$nparty/wxm:PartyID/@registerID,'«)')) else ('')"/>
		<xsl:variable name="sidspec" select="if (exists($nparty/wxm:RecipientSpecificPartyID)) then (concat('recipient specific ID »',$nparty/wxm:RecipientSpecificPartyID/text(),'«')) else ('')"/>
		<xsl:sequence select="f:concatID($sidwastex,$sidspec,$ssep)"/>
	</xsl:function>
	<xsl:function name="f:resolveCountryIDString" as="xs:string">
		<xsl:param name="lnodevalcontext" as="node()"/>
		<xsl:param name="sid" as="xs:string"/>
		<xsl:variable name="lnodeelem" select="$lnodevalcontext/wxm:ValidationNodeReferenceData/wxm:CountryList/wxm:ListElement[wxm:CountryID eq $sid]"/>
		<xsl:sequence select="if (exists($lnodeelem) and exists($lnodeelem/wxm:CountryTwoLetterID)) then (concat($lnodeelem/wxm:CountryTwoLetterID,' (ID »',$sid,'«)')) else (concat('»',$sid,'«'))"/>
	</xsl:function>
	<xsl:function name="f:quoteJoin" as="xs:string">
		<xsl:param name="ntext" as="node()*"/>
		<xsl:sequence select="if (count($ntext) eq 0) then ('') else (concat('»',string-join($ntext/text(),'«, »'),'«'))"/>
	</xsl:function>
	<pattern>
		<rule id="R011" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation">
			<report id="R011_chkcon" role="WARNING" test="(xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceiptInDatabaseIndicator) or xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:FacilityConfirmationOfWasteTreatmentInDatabaseIndicator) or xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:EntireConfirmationOfWasteTreatmentInDatabaseIndicator)) eq true()">The <sch:value-of select="f:msgTypeName(current())"/> refers to the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. The transmission of the <sch:value-of select="f:msgTypeName(current())"/> is late because for this combination of notification number and serial number the database at <sch:value-of select="f:valNodeName(current())"/> already contains the following: <sch:value-of select="string-join((for $m in f:availContentTypesShort(current()) return (if (($m eq 'movement announcement') or ($m eq 'carrier confirmation')) then '' else $m))[. != ''], ', ')"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R013" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<report id="R013_chkcon" role="WARNING" test="((xs:integer(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:CarrierConfirmationInDatabaseCount) gt 0) or xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceiptInDatabaseIndicator) or xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:FacilityConfirmationOfWasteTreatmentInDatabaseIndicator) or xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:EntireConfirmationOfWasteTreatmentInDatabaseIndicator)) eq true()">The movement announcement message refers to the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. The transmission of the movement announcement message is late because for this combination of notification number and serial number the database at <sch:value-of select="f:valNodeName(current())"/> already contains the following: <sch:value-of select="string-join((for $m in f:availContentTypesShort(current()) return (if ($m eq 'movement announcement') then '' else $m))[. != ''], ', ')"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R017" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<assert id="R017_prvalw" role="ERROR" test="exists(wxm:WasteProductionPartySite)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks information on the waste production (WasteProductionPartySite elements).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R044" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<report id="R044_uqstrc" role="INFO" test="(count(distinct-values(wxm:NationalRoute/wxm:CountryID)) ne count(wxm:NationalRoute/wxm:CountryID)) and (count(wxm:NationalRoute[exists(following-sibling::wxm:NationalRoute) and (wxm:CountryID eq (following-sibling::wxm:NationalRoute)[1]/wxm:CountryID)]) eq 0)">In the route information with points of exit and points of entry (NationalRoute elements) contained in the movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« the following countries, represented with their ISO 3166-1 3-digit codes<sch:value-of select="if (exists(/wxm:MessageValidationContext/wxm:ValidationNodeReferenceData/wxm:CountryList/wxm:ListElement/wxm:CountryTwoLetterID)) then ' and two-letter-codes' else ''"/>, occur more than once: <sch:value-of select="string-join((for $m in distinct-values(wxm:NationalRoute/wxm:CountryID) return if (count(wxm:NationalRoute[wxm:CountryID eq $m]) ge 2) then (if (exists(/wxm:MessageValidationContext/wxm:ValidationNodeReferenceData/wxm:CountryList/wxm:ListElement[wxm:CountryID eq $m]/wxm:CountryTwoLetterID)) then concat($m,' (',/wxm:MessageValidationContext/wxm:ValidationNodeReferenceData/wxm:CountryList/wxm:ListElement[wxm:CountryID eq $m]/wxm:CountryTwoLetterID,')') else $m) else '')[. != ''], ', ')"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R047" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt">
			<assert id="R047_prvalw" role="ERROR" test="exists(wxm:ReceiptDate)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the waste receipt date (ReceiptDate element).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R060" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation">
			<assert id="R060_prvalw" role="ERROR" test="exists(wxm:TransportModeID)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks transport mode information (TransportModeID element).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R066" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<report id="R066_chkcon" role="ERROR" test="count(wxm:NationalRoute) eq 1">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains country entry point and exit point information for a single country only.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R074" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:PlannedTreatmentCompletionDate">
			<assert id="R074_chkcon" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)) or (xs:date(.) ge (xs:date(/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)-xs:dayTimeDuration('P1D')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains the planned date of waste treatment completion »<sch:value-of select="."/>«. The message also contains the waste receipt date »<sch:value-of select="/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate"/>«. According to this data, the treatment is completed <sch:value-of select="days-from-duration(xs:date(/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)-xs:date(current()))"/> days before waste receipt. This error triggers for a waste treatment completion that is 2 or more days before waste receipt, leaving 1 day tolerance for time zone date progression differences.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R081" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteProductionPartySite">
			<assert id="R081_prvalw" role="ERROR" test="exists(wxm:SitePostalAreaID)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the post code (SitePostalAreaID element) for waste production site no. <sch:value-of select="1+count(preceding-sibling::*[name() eq name(current())])"/>, which refers to the waste production party with ID »<sch:value-of select="wxm:PartyID"/>« (»<sch:value-of select="current()/wxm:PartyID/@registerID"/>«).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R085" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteProductionPartySite">
			<report id="R085_chkref" role="ERROR" test="count(f:matchingPartySiteNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteProductionPartySite,current()/wxm:PartyID,current()/wxm:PartyID/@registerID,f:safeStringValue(current()/wxm:SitePostalAreaID))) gt 1">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to a waste production party with ID »<sch:value-of select="wxm:PartyID"/>« (»<sch:value-of select="current()/wxm:PartyID/@registerID"/>«) in combination with a production site with post code »<sch:value-of select="wxm:SitePostalAreaID"/>«. The notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> contains multiple waste production party and site combinations matching this party ID and site post code. As a result, the movement announcement does not uniquely reference a waste production entry of the notification.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R100" context="wxm:WasteMovementUserMessage/*/wxm:AnnouncementIdentity">
			<report id="R100_chkcon" role="ERROR" test="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StatusID eq 'CANCELLED'">The <sch:value-of select="f:msgTypeName(current())"/> refers to notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. In the database at <sch:value-of select="f:valNodeName(current())"/> the movement announcement for this combination of notification number and serial number is recorded as cancelled. As a result, <sch:value-of select="f:valNodeName(current())"/> cannot accept new messages referring to this combination of notification number and serial number.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R112" context="wxm:MovementAnnouncement/wxm:NationalRoute[position() ne last()]">
			<assert id="R112_prvalw" role="ERROR" test="exists(wxm:ExitPointName)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the exit point name (ExitPointName element) for route part no. <sch:value-of select="1+count(preceding-sibling::*[name() eq name(current())])"/> in country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,wxm:CountryID/text())"/>.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R114" context="wxm:WasteMovementUserMessage/wxm:MessageCreationUTCTimestamp">
			<report id="R114_chkcon" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp) and (xs:dateTime(current()) gt (xs:dateTime(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp)+xs:dayTimeDuration('PT5M')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains creation timestamp »<sch:value-of select="."/>« which lies in the future, i.e., it is greater than message receipt timestamp »<sch:value-of select="/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp"/>«.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R118" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<report id="R118_uqstrc" role="ERROR" test="not(exists(wxm:WasteProductionPartySite[not(exists(wxm:SitePostalAreaID))])) and count(distinct-values(wxm:WasteProductionPartySite/concat(wxm:PartyID,',',wxm:SitePostalAreaID))) ne count(wxm:WasteProductionPartySite)">In the movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« the following combinations of waste production party ID and waste production site postcode (WasteProductionPartySite elements) occur more than once: <sch:value-of select="string-join((for $m in distinct-values(wxm:WasteProductionPartySite/concat(wxm:PartyID,',',wxm:SitePostalAreaID)) return if (count(wxm:WasteProductionPartySite[(wxm:PartyID eq tokenize($m,',')[1]) and (wxm:SitePostalAreaID eq tokenize($m,',')[2])]) ge 2) then concat(tokenize($m,',')[1],', ',tokenize($m,',')[2]) else '')[. != ''], '; ')"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R129" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment">
			<assert id="R129_prvalw" role="ERROR" test="exists(wxm:TreatmentPartySite)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks treatment party and site information (TreatmentPartySite element).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R136" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiverPartySite">
			<report id="R136_prvcdn" role="ERROR" test="((count(f:matchingPartyNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite,current()/wxm:PartyID,current()/wxm:PartyID/@registerID)) ge 1) or (count(f:matchingPartyNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:SubsequentWasteTreatmentPartySite,current()/wxm:PartyID,current()/wxm:PartyID/@registerID)) ge 1)) and not(exists(wxm:SitePostalAreaID))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the post code for the waste receipt site (SitePostalAreaID element).</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R148" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation/wxm:CarrierPartyID">
			<report id="R148_chkcon" role="WARNING" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:TransportMovement) and (count(f:matchingTransportMovementNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:TransportMovement,current(),current()/@registerID)) lt 1)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the carrier party with ID »<sch:value-of select="."/>« (»<sch:value-of select="current()/@registerID"/>«). This does not match any of the carriers in the movement announcement information for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>. Note that for party IDs to match, the transmitted message must contain the correct type of ID (WasteX relevant ID or recipient specific ID), and <sch:value-of select="f:valNodeName(current())"/> must contain unique party IDs with the correct types as well.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R158" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:StartDate">
			<report id="R158_chkcon" role="WARNING" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ValidityEndDate) and (current() gt /wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ValidityEndDate)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains shipment start date »<sch:value-of select="."/>«. The notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> defines »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ValidityEndDate"/>« as the last day at which shipments are permitted. According to these records, the shipment will take place after the consented shipment period.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R170" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:AnnouncementIdentity">
			<report id="R170_chkcon" role="WARNING" xml:lang="en" test="(xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:NotificationInDatabaseIndicator) eq true()) and exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:MovementCount) and (xs:decimal(wxm:SequenceNumberID) gt xs:decimal( /wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:MovementCount))">The <sch:value-of select="f:msgTypeName(current())"/> refers to notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. In the database at <sch:value-of select="f:valNodeName(current())"/> the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« the total consented number of shipments is »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:MovementCount"/>«, which the serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« exceeds.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R200" context="wxm:WasteMovementUserMessage/wxm:MessageCreationUTCTimestamp">
			<report id="R200_chkcon" role="WARNING" test="exists(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp) and (xs:dateTime(current()) le (xs:dateTime(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp)-xs:dayTimeDuration('P5D')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains creation timestamp »<sch:value-of select="."/>«. According to this message creation timestamp and the message receipt timestamp »<sch:value-of select="/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp"/>« more than <sch:value-of select="days-from-duration(xs:dateTime(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp)-xs:dateTime(current()))"/> days have elapsed between message creation and message receipt. This warning triggers for time differences of 5 or more days.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R207" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteMass/wxm:NumericValue">
			<assert id="R207_chkcon" role="WARNING" test="not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedContentData/wxm:TotalWasteMass)) or not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteMass)) or ((xs:decimal(/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedContentData/wxm:TotalWasteMass)+xs:decimal(current())) le xs:decimal(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteMass))">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to <sch:value-of select="format-number(xs:decimal(.), '#,###.##')"/>
				<sch:value-of select="@unitID"/> of waste. According to the notification in the database at <sch:value-of select="f:valNodeName(current())"/> the total consented amount of waste is <sch:value-of select="format-number(xs:decimal(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteMass),'#,###.##')"/>
				<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteMass/@unitID"/>. According to the shipment information in the database at <sch:value-of select="f:valNodeName(current())"/> a total of <sch:value-of select="format-number(xs:decimal(/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedContentData/wxm:TotalWasteMass),'#,###.##')"/>
				<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedContentData/wxm:TotalWasteMass/@unitID"/> has already been announced or confirmed in receipt previously. As a result, the movement announcement exceeds the total consented amount of waste.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R219" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:StartDate">
			<assert id="R219_chkcon" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp)) or (xs:date(.) ge xs:date(format-dateTime(adjust-dateTime-to-timezone(xs:dateTime(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp), xs:dayTimeDuration('-PT12H'))-xs:dayTimeDuration('P2D'),'[Y]-[M,2]-[D,2]')))">
				<sch:value-of select="xs:date(format-dateTime(adjust-dateTime-to-timezone(xs:dateTime(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp), xs:dayTimeDuration('-PT12H'))-xs:dayTimeDuration('P2D'),'[Y]-[M,2]-[D,2]'))"/>The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains shipment start date »<sch:value-of select="."/>«. The message receipt timestamp is »<sch:value-of select="/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp"/>«, which means that more than <sch:value-of select="days-from-duration(xs:date(format-dateTime(adjust-dateTime-to-timezone(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp, xs:dayTimeDuration('-PT12H')),'[Y]-[M,2]-[D,2]'))-xs:date(current()))"/> days have elapsed between shipment start date and message receipt. This error triggers for a time difference of more than 1 day. Note that pursuant to provisions such as the WSR the information must be exchanged as an announcement, i.e., BEFORE the start of the shipment.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R226" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:ScopeID">
			<report id="R226_chkcon" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite) and not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:SubsequentWasteTreatmentPartySite)) and (. ne 'ENTIRE')">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to treatment at one facility, NOT including subsequent treatment (value »<sch:value-of select="."/>« in element ScopeID). According to the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>, there is NO subsequent treatment of waste for shipments under this consent. Confirmations of the completion of waste treatment must therefore refer to the completion of the ENTIRE treatment in the country of destination (Art. 16(e) WSR), by featuring the value »ENTIRE« in the ScopeID element.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R241" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:NationalRoute/wxm:EntryPointName">
			<let name="ncountrymatch" value="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country[wxm:CountryID eq current()/preceding-sibling::wxm:CountryID]"/>
			<report id="R241_chkref" role="INFO" test="(count($ncountrymatch) ge 1) and not(exists($ncountrymatch/wxm:EntryPointName[. eq current()/text()]))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to an entry point name »<sch:value-of select="."/>« for country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,preceding-sibling::wxm:CountryID/text())"/>. This does not match any of the entry point names - <sch:value-of select="f:quoteJoin($ncountrymatch/wxm:EntryPointName)"/> - from the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R247" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:NationalRoute[1]/wxm:CountryID">
			<report id="R247_chkref" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country) and (/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country[1]/wxm:CountryID ne current()/text())">In the movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« the first part of the route information refers to the country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,current()/text())"/>. The notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> contains country of dispatch <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country[1]/wxm:CountryID/text())"/>. The route must start in the country of dispatch.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R249" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt">
			<report id="R249_prvcdn" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteVolume) and not(exists(wxm:ReceivedWasteVolume))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks information on the received volume of waste (ReceivedWasteVolume element), despite the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> containing a consented maximum total volume of waste.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R253" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation/wxm:Date | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:TreatmentCompletionDate">
			<assert id="R253_chkcon" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp)) or (xs:date(.) ge (xs:date(format-dateTime(adjust-dateTime-to-timezone(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp, xs:dayTimeDuration('-PT12H')),'[Y]-[M,2]-[D,2]'))-xs:dayTimeDuration('P30D')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains <sch:value-of select="f:dateName(current())"/> »<sch:value-of select="."/>«. The message receipt timestamp is »<sch:value-of select="/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp"/>«, which means that more than <sch:value-of select="days-from-duration(xs:date(format-dateTime(adjust-dateTime-to-timezone(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp, xs:dayTimeDuration('-PT12H')),'[Y]-[M,2]-[D,2]'))-xs:date(current()))"/> days have elapsed between <sch:value-of select="f:dateName(current())"/> and message receipt. This error triggers for a time difference of more than 30 days. Note that there are many provisions in practice, such as WSR or consent provisions, that can require transmissions sooner than within 30 days.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R259" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteProductionPartySite">
			<assert id="R259_chkref" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteProductionPartySite)) or not(exists(wxm:SitePostalAreaID)) or (count(f:matchingPartySiteNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteProductionPartySite,current()/wxm:PartyID,current()/wxm:PartyID/@registerID,f:safeStringValue(current()/wxm:SitePostalAreaID))) ge 1)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to a waste production party with ID »<sch:value-of select="wxm:PartyID"/>« (»<sch:value-of select="current()/wxm:PartyID/@registerID"/>«) in combination with a production site with post code »<sch:value-of select="wxm:SitePostalAreaID"/>«. This does not match any of the waste production party-site-combinations in the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>. Note that for party IDs to match, the transmitted message must contain the correct type of ID (WasteX relevant ID or recipient specific ID), and <sch:value-of select="f:valNodeName(current())"/> must contain unique party IDs with the correct types as well.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R279" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiverPartySite/wxm:PartyID">
			<report id="R279_chkcon" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID[(. eq current()/text()) and (@registerID eq current()/@registerID)]))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the waste receiver party with ID »<sch:value-of select="."/>« (»<sch:value-of select="current()/@registerID"/>«). This does not match the message creation party with ID »<sch:value-of select="/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID"/>« (»<sch:value-of select="/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID/@registerID"/>«).</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R305" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:ScopeID">
			<report id="R305_chkcon" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite) and exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:SubsequentWasteTreatmentPartySite) and (. ne 'FACILITY')">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the completion of the ENTIRE treatment in the country of destination (value »<sch:value-of select="."/>« in element ScopeID). According to the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>, there is subsequent treatment of waste for shipments under this consent. This version of the WasteX specification does NOT support confirmations of the completion of subsequent treatment (Art. 15(e) WSR), but rather supports confirmations of the completion of interim treatment only (Art. 15(d) WSR). For the confirmation of the completion of interim treatment, the ScopeID element must feature the value »FACILITY«.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R307" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt">
			<assert id="R307_prvalw" role="WARNING" test="exists(wxm:PlannedTreatmentCompletionDate)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the planned date of completing waste treatment (PlannedTreatmentCompletionDate element).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R323" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation/wxm:Date | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:TreatmentCompletionDate">
			<report id="R323_chkcon" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp) and (xs:string(.) gt format-dateTime(adjust-dateTime-to-timezone(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp, xs:dayTimeDuration('PT14H')),'[Y]-[M,2]-[D,2]'))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains <sch:value-of select="f:dateName(current())"/> »<sch:value-of select="."/>« which lies in the future, i.e., it is greater than message receipt timestamp »<sch:value-of select="/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp"/>«.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R342" context="wxm:WasteMovementUserMessage/*[not(contains(local-name(),'Status'))]/wxm:AnnouncementIdentity">
			<report id="R342_chkcon" role="INFO" xml:lang="en" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedChangeData/wxm:ShipmentRecordContentUpdateCount) and (xs:integer(/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedChangeData/wxm:ShipmentRecordContentUpdateCount) ge 1)">The <sch:value-of select="f:msgTypeName(current())"/> refers to notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. Content of the respective type already exists in the database at <sch:value-of select="f:valNodeName(current())"/> and has been updated at least once prior to the receipt of the new message. The WasteX protocol expects single transmissions of 'final' information as the standard case, and the avoidance of update/correction-transmissions to the greatest extent possible.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R356" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation/wxm:CarrierPartyID">
			<report id="R356_chkcon" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:CarrierParty) and (count(f:matchingPartyNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:CarrierParty, current(), current()/@registerID)) ne 1)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the carrier with ID »<sch:value-of select="."/>« (»<sch:value-of select="current()/@registerID"/>«). This does not match any of the carriers in the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>. Note that for party IDs to match, the transmitted message must contain the correct type of ID (WasteX relevant ID or recipient specific ID), and <sch:value-of select="f:valNodeName(current())"/> must contain unique party IDs with the correct types as well.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R369" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:NationalRoute/wxm:CountryID">
			<report id="R369_chkref" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeReferenceData/wxm:CountryList) and not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeReferenceData/wxm:CountryList/wxm:ListElement[wxm:CountryID eq current()/text()]))">The route information in the movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to a country with ISO 3166-1 3-digit code »<sch:value-of select="."/>«. A country with this ID does not exist in the reference data at <sch:value-of select="f:valNodeName(current())"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R378" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<assert id="R378_prvalw" role="ERROR" test="count(wxm:PackageTypeID) ge 1">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks packaging type information (PackageTypeID elements).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R387" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:NationalRoute[last()]/wxm:CountryID">
			<report id="R387_chkref" role="ERROR" test="(count(../../wxm:NationalRoute) ge 2) and (exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country)) and (/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country[last()]/wxm:CountryID ne current()/text())">In the movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« the last part of the route information refers to the country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,current()/text())"/>. The notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> contains country of destination <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country[last()]/wxm:CountryID/text())"/>. The route must end in the country of destination.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R418" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation">
			<assert id="R418_prvalw" role="WARNING" test="exists(wxm:TransportMeansID)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks a transport means identifier, such as a license plate number (TransportMeansID element).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R426" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:TreatmentCompletionDate">
			<assert id="R426_chkcon" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)) or (xs:date(.) ge (xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)-xs:dayTimeDuration('P1D')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains <sch:value-of select="f:dateName(current())"/> »<sch:value-of select="."/>«. For the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«, the database at <sch:value-of select="f:valNodeName(current())"/> contains waste receipt information with receipt date »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate"/>«. According to this data, the <sch:value-of select="f:dateName(current())"/> is <sch:value-of select="days-from-duration(xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)-xs:date(current()))"/> days before the receipt date. This error triggers for a <sch:value-of select="f:dateName(current())"/> that is 2 or more days before the receipt date, leaving 1 day tolerance for time zone date progression differences.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R439" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<assert id="R439_prvalw" role="ERROR" test="exists(wxm:StartDate)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the shipment start date (StartDate element).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R446" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:NationalRoute/wxm:CountryID">
			<report id="R446_chkcon" role="ERROR" test="exists(parent::*/preceding-sibling::wxm:NationalRoute) and (parent::*/preceding-sibling::wxm:NationalRoute[1]/wxm:CountryID eq current()/text())">The route information with points of exit and points of entry in the movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the same country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,current()/text())"/> in two consecutive route parts, no. <sch:value-of select="count(parent::*/preceding-sibling::wxm:NationalRoute)"/> and <sch:value-of select="1+count(parent::*/preceding-sibling::wxm:NationalRoute)"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R470" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceivedWasteMass | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceivedWasteVolume">
			<report id="R470_chkval" role="INFO" test="xs:decimal(wxm:NumericValue) eq 0.0">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains a waste <sch:value-of select="if (contains(local-name(.),'Volume')) then 'volume' else 'mass'"/> value of »0.0«.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R473" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:NationalRoute/wxm:CountryID">
			<report id="R473_chkcon" role="WARNING" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeReferenceData/wxm:CountryList) and exists(../../wxm:StartDate) and exists(/wxm:MessageValidationContext/wxm:ValidationNodeReferenceData/wxm:CountryList/wxm:ListElement[wxm:CountryID eq current()/text()]/wxm:ValidityEndDate) and (xs:string(/wxm:MessageValidationContext/wxm:ValidationNodeReferenceData/wxm:CountryList/wxm:ListElement[wxm:CountryID eq current()/text()]/wxm:ValidityEndDate) le xs:string(../../wxm:StartDate))">The route information in the movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,current()/text())"/>. According to the reference data at <sch:value-of select="f:valNodeName(current())"/> this country ceased to exist at <sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeReferenceData/wxm:CountryList/wxm:ListElement[wxm:CountryID eq current()/text()]/wxm:ValidityEndDate"/>, and therefore should NOT be referenced in the movement announcement with start date <sch:value-of select="../../wxm:StartDate"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R479" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:PackageTypeID">
			<report id="R479_chkref" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:PackageTypeID) and not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:PackageTypeID[. eq current()/text()]))">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the packaging type with code »<sch:value-of select="."/>«. In the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> the type with code »<sch:value-of select="."/>« is not among the consented packaging types.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R489" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt">
			<report id="R489_prvcdn" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteMass) and not(exists(wxm:ReceivedWasteMass))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks information on the received mass of waste (ReceivedWasteMass element), despite the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> containing a consented maximum total mass of waste.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R493" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment">
			<assert id="R493_prvalw" role="ERROR" test="exists(wxm:TreatmentCompletionDate)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the treatment completion date (TreatmentCompletionDate element).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R495" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<report id="R495_prvcdn" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteMass) and not(exists(wxm:WasteMass))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks information on the mass of waste to be shipped (WasteMass element), despite the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> containing a consented maximum total mass of waste.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R497" context="wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID">
			<report id="R497_chkcon" role="ERROR" test="(exists(../wxm:MovementAnnouncement) or exists(../wxm:MovementAnnouncementStatus)) and exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:NotifierParty) and (count(f:matchingPartyNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:NotifierParty, current(), current()/@registerID)) ne 1)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to a message creation party with ID »<sch:value-of select="."/>« (»<sch:value-of select="current()/@registerID"/>«). This is different from the notification party reference in the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>, which contains <sch:value-of select="f:listPartyID(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:NotifierParty,' and ')"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R519" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<report id="R519_uqstrc" role="ERROR" test="count(distinct-values(wxm:PackageTypeID)) ne count(wxm:PackageTypeID)">In the packaging type information (PackageTypeID elements) contained in the movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« the following packaging types occur more than once: <sch:value-of select="string-join((for $m in distinct-values(wxm:PackageTypeID) return if (count(wxm:PackageTypeID[. eq $m]) ge 2) then $m else '')[. != ''], ', ')"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R521" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:TransportMovement/wxm:CarrierPartyID">
			<assert id="R521_chkref" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:CarrierParty)) or (count(f:matchingPartyNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:CarrierParty,current(),current()/@registerID)) eq 1)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to a carrier party with ID »<sch:value-of select="."/>« (»<sch:value-of select="current()/@registerID"/>«). This does not match any of the carrier parties in the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« at the <sch:value-of select="f:valNodeName(current())"/> database. Note that for party IDs to match, the transmitted message must contain the correct type of ID (WasteX relevant ID or recipient specific ID), and <sch:value-of select="f:valNodeName(current())"/> must contain unique party IDs with the correct types as well.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R522" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<report id="R522_prvalw" role="WARNING" test="not(exists(wxm:PackageCount))">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the total number of packages (PackageCount element).</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R526" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:NationalRoute/wxm:ExitPointName">
			<let name="ncountrymatch" value="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country[wxm:CountryID eq current()/preceding-sibling::wxm:CountryID]"/>
			<report id="R526_chkref" role="INFO" test="(count($ncountrymatch) ge 1) and not(exists($ncountrymatch/wxm:ExitPointName[. eq current()/text()]))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to an exit point name »<sch:value-of select="."/>« for country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,preceding-sibling::wxm:CountryID/text())"/>. This does not match any of the exit point names - <sch:value-of select="f:quoteJoin($ncountrymatch/wxm:ExitPointName)"/> - from the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R530" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteMass | wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteVolume | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceivedWasteMass | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceivedWasteVolume">
			<report id="R530_chkval" role="ERROR" test="xs:decimal(wxm:NumericValue) lt 0.0">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains a negative waste <sch:value-of select="if (contains(local-name(.),'Volume')) then 'volume' else 'mass'"/> value »<sch:value-of select="wxm:NumericValue"/>«.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R533" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:TreatmentCompletionDate">
			<assert id="R533_chkcon" role="WARNING" test="not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)) or (xs:date(.) le (xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)+xs:dayTimeDuration('P366D')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains <sch:value-of select="f:dateName(current())"/> »<sch:value-of select="."/>«. For the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«, the database at <sch:value-of select="f:valNodeName(current())"/> contains waste receipt information with receipt date »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate"/>«. According to this data, the <sch:value-of select="f:dateName(current())"/> is <sch:value-of select="days-from-duration(xs:date(current())-xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate))"/> days after the waste receipt date. This warning triggers for a <sch:value-of select="f:dateName(current())"/> that is more than 366 days after the waste receipt date.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R557" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteMass | wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteVolume">
			<report id="R557_chkval" role="ERROR" test="xs:decimal(wxm:NumericValue) eq 0.0">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains a waste <sch:value-of select="if (contains(local-name(.),'Volume')) then 'volume' else 'mass'"/> value of »0.0«.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R564" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiverPartySite">
			<report id="R564_chkref" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite) and exists(wxm:SitePostalAreaID) and (count(f:matchingPartySiteNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite,wxm:PartyID,wxm:PartyID/@registerID,f:safeStringValue(current()/wxm:SitePostalAreaID))) eq 0) and (count(f:matchingPartyNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ConsigneeParty,wxm:PartyID,wxm:PartyID/@registerID)) eq 0)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the waste receiver party with ID »<sch:value-of select="wxm:PartyID"/>« (»<sch:value-of select="wxm:PartyID/@registerID"/>«)<sch:value-of select="if (exists(wxm:SitePostalAreaID)) then concat(' and receipt site with post code »',xs:string(wxm:SitePostalAreaID),'«') else ''"/>. The <sch:value-of select="if (exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:SubsequentWasteTreatmentPartySite)) then 'first ' else ''"/>waste treatment party and site in the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> has <sch:value-of select="f:listPartyID(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite,', ')"/> and post code »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite/wxm:SitePostalAreaID"/>«, which does not match.<sch:value-of select="if (exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ConsigneeParty)) then (concat(' The consignee party in the notification/consent has ',f:listPartyID(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ConsigneeParty,' and '),', which does not match either.')) else ''"/>
			</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R576" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:StartDate">
			<report id="R576_chkcon" role="WARNING" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ValidityStartDate) and (current() lt /wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ValidityStartDate)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains shipment start date »<sch:value-of select="."/>«. The notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> defines »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ValidityStartDate"/>« as the first day at which shipments are permitted. According to these records, the shipment takes place before the consented shipment period.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R602" context="wxm:SequenceNumberID">
			<report id="R602_chkval" role="ERROR" test="xs:integer(.) lt 1">The <sch:value-of select="f:msgTypeName(current())"/> for notification number »<sch:value-of select="f:msgNotID(current())"/>« refers to serial number »<sch:value-of select="."/>«. The serial number must be geater or equal to 1.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R606" context="wxm:MovementAnnouncement/wxm:NationalRoute[position() eq 1]">
			<report id="R606_prvalw" role="ERROR" test="exists(wxm:EntryPointName)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains the entry point name »<sch:value-of select="wxm:EntryPointName"/>« for the first part of the route in country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,wxm:CountryID/text())"/>. The first part of the route must not contain an entry point name.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R614" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncementStatus">
			<report id="R614_chkcon" role="ERROR" test="((xs:integer(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:CarrierConfirmationInDatabaseCount) gt 0) or xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceiptInDatabaseIndicator) or xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:FacilityConfirmationOfWasteTreatmentInDatabaseIndicator) or xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:EntireConfirmationOfWasteTreatmentInDatabaseIndicator)) eq true()">The movement announcement cancellation (movement announcement status message) refers to the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. <sch:value-of select="f:valNodeName(current())"/> cannot accept/process the cancellation, as for this combination of notification number and serial number, the database at <sch:value-of select="f:valNodeName(current())"/> already contains the following: <sch:value-of select="string-join((for $m in f:availContentTypesShort(current()) return (if ($m eq 'movement announcement') then '' else $m))[. != ''], ', ')"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R631" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation/wxm:Date | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:TreatmentCompletionDate">
			<assert id="R631_chkcon" role="WARNING" test="not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate)) or (xs:date(.) ge (xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate)-xs:dayTimeDuration('P1D')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains <sch:value-of select="f:dateName(current())"/> »<sch:value-of select="."/>«. For the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«, the database at <sch:value-of select="f:valNodeName(current())"/> contains movement announcement information with shipment start date »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate"/>«. According to this data, the <sch:value-of select="f:dateName(current())"/> is <sch:value-of select="days-from-duration(xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate)-xs:date(current()))"/> days before the shipment start date. This warning triggers for a <sch:value-of select="f:dateName(current())"/> that is 2 or more days before the shipment start date, leaving 1 day tolerance for time zone date progression differences.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R651" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt">
			<report id="R651_chkcon" role="WARNING" test="(xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:FacilityConfirmationOfWasteTreatmentInDatabaseIndicator) or xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:EntireConfirmationOfWasteTreatmentInDatabaseIndicator)) eq true()">The <sch:value-of select="f:msgTypeName(current())"/> refers to the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. The transmission of the <sch:value-of select="f:msgTypeName(current())"/> is late because for this combination of notification number and serial number the database at <sch:value-of select="f:valNodeName(current())"/> already contains the following: <sch:value-of select="string-join((for $m in f:availContentTypesShort(current()) return (if (($m eq 'movement announcement') or ($m eq 'carrier confirmation') or ($m eq 'confirmation of waste receipt')) then '' else $m))[. != ''], ', ')"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R684" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<report id="R684_prvcdn" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteVolume) and not(exists(wxm:WasteVolume))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks information on the volume of waste to be shipped (WasteVolume element), despite the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> containing a consented maximum total volume of waste.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R686" context="wxm:MovementAnnouncement/wxm:NationalRoute[position() ne 1]">
			<assert id="R686_prvalw" role="ERROR" test="exists(wxm:EntryPointName)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the entry point name (EntryPointName element) for route part no. <sch:value-of select="1+count(preceding-sibling::*[name() eq name(current())])"/> in country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,wxm:CountryID/text())"/>.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R688" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncementStatus/wxm:AnnouncementIdentity">
			<report id="R688_chkcon" role="WARNING" xml:lang="en" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncementInDatabaseIndicator) and (xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncementInDatabaseIndicator) eq false())">The <sch:value-of select="f:msgTypeName(current())"/> (announcement cancellation) refers to notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. In the database at <sch:value-of select="f:valNodeName(current())"/> there is no movement announcement for this combination of notification number and serial number. As a result, <sch:value-of select="f:valNodeName(current())"/> ignores the message.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R705" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<assert id="R705_prvalw" role="WARNING" test="exists(wxm:NationalRoute)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks country entry point and exit point information (NationalRoute elements).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R712" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:StartDate">
			<assert id="R712_chkcon" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp)) or (xs:date(.) le xs:date(format-dateTime(xs:dateTime(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp)+xs:yearMonthDuration('P1Y'),'[Y]-[M,2]-[D,2]')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains shipment start date »<sch:value-of select="."/>«. The message receipt timestamp is »<sch:value-of select="/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp"/>«, which means that from the time of message receipt it still takes more than <sch:value-of select="days-from-duration(xs:date(.)-xs:date(format-dateTime(xs:dateTime(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp),'[Y]-[M,2]-[D,2]'))) idiv 365.25"/> years until the shipment starts. This error triggers for a time difference of 1 or more years.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R715" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:AnnouncementIdentity">
			<report id="R715_chkcon" role="WARNING" xml:lang="en" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceiptInDatabaseIndicator) and (xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:ConfirmationOfWasteReceiptInDatabaseIndicator) eq false())">The <sch:value-of select="f:msgTypeName(current())"/> refers to notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. In the database at <sch:value-of select="f:valNodeName(current())"/> there is no confirmation of waste receipt for this combination of notification number and serial number at the time of <sch:value-of select="f:msgTypeName(current())"/> receipt.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R725" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation">
			<report id="R725_chkcon" role="INFO" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeName) and (/wxm:MessageValidationContext/wxm:ValidationNodeName eq 'edm.gv.at')">AT: Note that for the time being the WasteX interface of the Austrian competent authority cannot store carrier confirmations. The competent authority will not have access to transmitted carrier confirmations.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R726" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt">
			<assert id="R726_prvalw" role="ERROR" test="exists(wxm:RejectionIndicator)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the indication of whether or not the received waste was rejected (RejectionIndicator element).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R732" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:TransportMovement">
			<let name="nmatchcarrier" value="f:matchingPartyNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:CarrierParty,current()/wxm:CarrierPartyID,current()/wxm:CarrierPartyID/@registerID)"/>
			<report id="R732_chkref" role="WARNING" test="exists(wxm:TransportModeID) and (count($nmatchcarrier) eq 1) and not(exists($nmatchcarrier/wxm:TransportModeID[. eq current()/wxm:TransportModeID]))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the combination of transport mode »<sch:value-of select="wxm:TransportModeID"/>« and carrier party with ID »<sch:value-of select="current()/wxm:CarrierPartyID"/>« (»<sch:value-of select="current()/wxm:CarrierPartyID/@registerID"/>«). The notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> does NOT contain this combination of transport mode and carrier party. The notification/consent contains the following transport modes for the party: <sch:value-of select="string-join(distinct-values($nmatchcarrier/wxm:TransportModeID), ', ')"/>
			</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R767" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:TreatmentPartySite">
			<report id="R767_chkref" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite) and exists(wxm:SitePostalAreaID) and (count(f:matchingPartySiteNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite,current()/wxm:PartyID,current()/wxm:PartyID/@registerID,f:safeStringValue(current()/wxm:SitePostalAreaID))) eq 0)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the waste treatment party with ID »<sch:value-of select="wxm:PartyID"/>« (»<sch:value-of select="wxm:PartyID/@registerID"/>«) and treatment site post code »<sch:value-of select="wxm:SitePostalAreaID"/>«. The <sch:value-of select="if (exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:SubsequentWasteTreatmentPartySite)) then 'first ' else ''"/>waste treatment party and site in the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> has <sch:value-of select="f:listPartyID(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite,', ')"/> and post code »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite/wxm:SitePostalAreaID"/>«, which does not match.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R780" context="wxm:WasteMovementUserMessage/*/wxm:AnnouncementIdentity/wxm:NotificationID">
			<report id="R780_chkref" role="ERROR" xml:lang="en" test="xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:NotificationInDatabaseIndicator) eq false()">The <sch:value-of select="f:msgTypeName(current())"/> refers to notification number »<sch:value-of select="f:msgNotID(current())"/>«. A notification with that number does not exist in the database at <sch:value-of select="f:valNodeName(current())"/>.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R795" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation/wxm:AnnouncementIdentity | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:AnnouncementIdentity | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:AnnouncementIdentity">
			<report id="R795_chkcon" role="WARNING" xml:lang="en" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncementInDatabaseIndicator) and (xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncementInDatabaseIndicator) eq false())">The <sch:value-of select="f:msgTypeName(current())"/> refers to notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. In the database at <sch:value-of select="f:valNodeName(current())"/> there is no movement announcement for this combination of notification number and serial number at the time of <sch:value-of select="f:msgTypeName(current())"/> receipt.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R797" context="wxm:WasteMovementUserMessage/*/wxm:AnnouncementIdentity">
			<report id="R797_chkcon" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:PartyIdentifierCompleteIndicator) and (xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:PartyIdentifierCompleteIndicator) eq false())">The <sch:value-of select="f:msgTypeName(current())"/> refers to notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. The notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> lacks party identifiers needed for looking up party references contained in WasteX messages. This applies to one or more of the following parties: Notifier, waste producers, carriers, consignee and/or waste treatment parties.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R798" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement">
			<assert id="R798_prvalw" role="ERROR" test="count(wxm:TransportMovement) ge 1">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks carrier information (TransportMovement elements).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R804" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncementStatus">
			<assert id="R804_chkcon" role="WARNING" test="not(exists(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp)) or not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate)) or (xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate) ge xs:date(format-dateTime(adjust-dateTime-to-timezone(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp, xs:dayTimeDuration('-PT12H'))-xs:dayTimeDuration('P2D'),'[Y]-[M,2]-[D,2]')))">The <sch:value-of select="f:msgTypeName(current())"/> refers to notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. For this combination of notification number and serial number, the database at <sch:value-of select="f:valNodeName(current())"/> contains latest movement announcement information with start date »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate"/>«. The receipt timestamp for the <sch:value-of select="f:msgTypeName(current())"/> is »<sch:value-of select="/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp"/>«, which means that more than <sch:value-of select="days-from-duration(xs:date(format-dateTime(adjust-dateTime-to-timezone(/wxm:MessageValidationContext/wxm:EDIInteractionUTCTimestamp, xs:dayTimeDuration('-PT12H')),'[Y]-[M,2]-[D,2]'))-xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate))"/> days have elapsed between shipment start date and message receipt. This warning triggers for a posteriori announcement status updates (cancellations) with a time difference of more than 1 day. Note that pursuant to provisions such as the WSR the information must be exchanged as an announcement, i.e., BEFORE the start of the shipment.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R808" context="wxm:PackageCount">
			<report id="R808_chkval" role="ERROR" test="xs:integer(.) lt 0">The <sch:value-of select="f:msgTypeName(current())"/> for notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains the number of packages »<sch:value-of select="."/>«. The number of packages must be greater or equal to 0.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R824" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:NationalRoute/wxm:CountryID">
			<report id="R824_chkref" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country) and not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:Country[wxm:CountryID eq current()/text()]))">The route information in the movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,current()/text())"/>. According to the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>, this country is neither country of dispatch, nor country of transit, nor country of destination. The route information must match country of dispatch, countries of transit and country of destination from the notification/consent.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R827" context="wxm:WasteMovementUserMessage">
			<report id="R827_chkcon" role="WARNING" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:MovementPermissionStatusIndicator) and (xs:boolean(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:MovementPermissionStatusIndicator) eq false())">The <sch:value-of select="f:msgTypeName(current())"/> refers to notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«. According to the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> the status of the notification and consent procedure is such that shipments are not or not yet permitted.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R837" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteVolume/wxm:NumericValue">
			<assert id="R837_chkcon" role="WARNING" test="not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedContentData/wxm:TotalWasteVolume)) or not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteVolume)) or ((xs:decimal(/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedContentData/wxm:TotalWasteVolume)+xs:decimal(current())) le xs:decimal(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteVolume))">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to <sch:value-of select="format-number(xs:decimal(.), '#,###.##')"/>
				<sch:value-of select="@unitID"/> of waste. According to the notification in the database at <sch:value-of select="f:valNodeName(current())"/> the total consented amount of waste is <sch:value-of select="format-number(xs:decimal(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteVolume),'#,###.##')"/>
				<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteVolume/@unitID"/>. According to the shipment information in the database at <sch:value-of select="f:valNodeName(current())"/> a total of <sch:value-of select="format-number(xs:decimal(/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedContentData/wxm:TotalWasteVolume),'#,###.##')"/>
				<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeAggregatedContentData/wxm:TotalWasteVolume/@unitID"/> has already been announced or confirmed in receipt previously. As a result, the movement announcement exceeds the total consented amount of waste.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R849" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:PlannedTreatmentCompletionDate">
			<assert id="R849_chkcon" role="WARNING" test="not(exists(/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)) or (xs:date(.) le (xs:date(/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate)+xs:dayTimeDuration('P366D')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains the planned date of waste treatment completion »<sch:value-of select="."/>«. The message also contains the waste receipt date »<sch:value-of select="/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate"/>«. According to this data, the treatment is completed <sch:value-of select="days-from-duration(xs:date(current())-xs:date(/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate))"/> days after the waste receipt. This warning triggers for a waste treatment completion that is more than 366 days after the waste receipt date.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R852" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiverPartySite/wxm:PartyID">
			<report id="R852_chkcon" role="ERROR" test="exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite) and exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ConsigneeParty) and ((/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite/wxm:PartyID ne /wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ConsigneeParty/wxm:PartyID) or (/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:WasteTreatmentPartySite/wxm:PartyID/@registerID ne /wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ConsigneeParty/wxm:PartyID/@registerID)) and (count(f:matchingPartyNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:ConsigneeParty,current(),current()/@registerID)) ge 1)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the waste receiver party with ID »<sch:value-of select="."/>« (»<sch:value-of select="current()/@registerID"/>«). This matches the consignee party from the notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/>, but does NOT match the <sch:value-of select="if (exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:SubsequentWasteTreatmentPartySite)) then 'first ' else ''"/>waste treatment party. This version of the WasteX specification does NOT support Annex IB Block 17 WSR confirmations by consignees, but rather only supports Annex IB Block 18 confirmations by waste treatment parties.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R899" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:TreatmentPartySite/wxm:PartyID">
			<report id="R899_chkcon" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID[(. eq current()/text()) and (@registerID eq current()/@registerID)]))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the waste treatment party with ID »<sch:value-of select="."/>« (»<sch:value-of select="current()/@registerID"/>«). This does not match the message creation party with ID »<sch:value-of select="/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID"/>« (»<sch:value-of select="/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID/@registerID"/>«).</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R902" context="wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteTreatment/wxm:TreatmentPartySite">
			<assert id="R902_prvalw" role="ERROR" test="exists(wxm:SitePostalAreaID)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the treatment site post code (SitePostalAreaID element).</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R938" context="*[exists(@xsi:type)]">
			<report id="R938_prvalw" role="ERROR" test="true()">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«  CONTAINS XML attribute »xsi:type« (»type« attribute of namespace »http://www.w3.org/2001/XMLSchema-instance«). The data format does not support »xsi:type« attributes.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R952" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteMass|wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteVolume|wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceivedWasteMass|wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceivedWasteVolume">
			<assert id="R952_prvalw" role="WARNING" test="exists(wxm:QuantificationTypeID)">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« lacks the quantification type (QuantificationTypeID element) in the <sch:value-of select="if (contains(local-name(current()),'Volume')) then 'volume' else 'mass'"/> information. This means that it lacks the information whether the value is measured, calculated or estimated.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R959" context="wxm:MovementAnnouncement/wxm:NationalRoute[(position() eq last()) and (position() ge 2)]">
			<report id="R959_prvalw" role="ERROR" test="exists(wxm:ExitPointName)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains the exit point name »<sch:value-of select="wxm:ExitPointName"/>« for the last part of the route in country <sch:value-of select="f:resolveCountryIDString(/wxm:MessageValidationContext,wxm:CountryID/text())"/>. The last part of the route must not contain an exit point name.</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R967" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation/wxm:CarrierPartyID">
			<report id="R967_chkcon" role="ERROR" test="not(exists(/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID[(. eq current()/text()) and (@registerID eq current()/@registerID)]))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the carrier with ID »<sch:value-of select="."/>« (»<sch:value-of select="current()/@registerID"/>«). This does not match the message creation party with ID »<sch:value-of select="/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID"/>« (»<sch:value-of select="/wxm:MessageValidationContext/wxm:WasteMovementUserMessage/wxm:MessageCreationPartyID/@registerID"/>«).</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R971" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation">
			<let name="nmatchcarrier" value="f:matchingPartyNodes(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:Notification/wxm:CarrierParty,current()/wxm:CarrierPartyID,current()/wxm:CarrierPartyID/@registerID)"/>
			<report id="R971_chkref" role="WARNING" test="exists(wxm:TransportModeID) and (count($nmatchcarrier) ge 1) and not(exists($nmatchcarrier/wxm:TransportModeID[. eq current()/wxm:TransportModeID]))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to the combination of transport mode »<sch:value-of select="wxm:TransportModeID"/>« and carrier party with ID »<sch:value-of select="current()/wxm:CarrierPartyID"/>« (»<sch:value-of select="current()/wxm:CarrierPartyID/@registerID"/>«). The notification/consent entry for »<sch:value-of select="f:msgNotID(current())"/>« in the database at <sch:value-of select="f:valNodeName(current())"/> does NOT contain this combination of transport mode and carrier party. The notification/consent contains the following transport modes for the party: <sch:value-of select="string-join(distinct-values($nmatchcarrier/wxm:TransportModeID), ', ')"/>
			</report>
		</rule>
	</pattern>
	<pattern>
		<rule id="R979" context="wxm:WasteMovementUserMessage/wxm:CarrierConfirmation/wxm:Date | wxm:WasteMovementUserMessage/wxm:ConfirmationOfWasteReceipt/wxm:ReceiptDate">
			<assert id="R979_chkcon" role="WARNING" test="not(exists(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate)) or (xs:date(.) le (xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate)+xs:dayTimeDuration('P200D')))">The <sch:value-of select="f:msgTypeName(current())"/> for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« contains <sch:value-of select="f:dateName(current())"/> »<sch:value-of select="."/>«. For the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>«, the database at <sch:value-of select="f:valNodeName(current())"/> contains movement announcement information with shipment date »<sch:value-of select="/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate"/>«. According to this data, the <sch:value-of select="f:dateName(current())"/> is <sch:value-of select="days-from-duration(xs:date(current())-xs:date(/wxm:MessageValidationContext/wxm:ValidationNodeIndividualData/wxm:MovementAnnouncement/wxm:StartDate))"/> days after the shipment start date. This warning triggers for a <sch:value-of select="f:dateName(current())"/> that is 200 days or more after the shipment start date.</assert>
		</rule>
	</pattern>
	<pattern>
		<rule id="R987" context="wxm:WasteMovementUserMessage/wxm:MovementAnnouncement/wxm:WasteMass/wxm:NumericValue">
			<report id="R987_chkval" role="INFO" test="(not(exists(../../wxm:TransportMovement[1]/wxm:TransportModeID)) or (../../wxm:TransportMovement[1]/wxm:TransportModeID eq 'R')) and (xs:decimal(.) ge 35)">The movement announcement message for the combination of notification number »<sch:value-of select="f:msgNotID(current())"/>« and serial number »<sch:value-of select="f:msgSeqNumID(current())"/>« refers to <sch:value-of select="format-number(xs:decimal(.), '#,###.##')"/>
				<sch:value-of select="@unitID"/> of waste. A waste mass greater or equal to 35t is considered unusually high for a single shipment of waste with transport on road.</report>
		</rule>
	</pattern>
</schema>
